import 'source-map-support/register';
import * as DockerModels from './dockerModels';
export interface NetworkMap {
    [id: string]: DockerModels.Network;
}
export interface VolumeMap {
    [name: string]: DockerModels.Volume;
}
/**
 * Generate a docker-compose string from a list of JSON service documents
 *
 * @param services Array of Services to generate a compose file from
 * @param networks Map of network ID -> network name
 */
export declare function compose(services: DockerModels.Service[], networkMap: NetworkMap, volumeMap: VolumeMap): string;
/**
 * Creates a map of volume name => volume and normalizes the volume name
 * @param volumes
 */
export declare function createVolumeMap(volumes: DockerModels.Volume[]): VolumeMap;
/**
 * Create a network map to allow generating a docker-compose file
 * @param networks Array of Network objects from Docker
 */
export declare function createNetworkMap(networks: DockerModels.Network[]): NetworkMap;
/**
 * Return a list of network IDs that require inspection
 *
 * This is required to create a NetworkMap
 * @param services
 */
export declare function getNetworkIds(services: DockerModels.Service[]): string[];
export default compose;
